pub enum ApiError {
UrlError,
AliasError,
PasswordError,
MaxClicksError,
EmojiError,
RateLimitExceeded,
Other(String),
}Expand description
Errors that can occur when interacting with the spoo.me API.
Variants
UrlError
The URL does not match the expected format.
AliasError
The alias is already in use or invalid.
PasswordError
The password provided is incorrect.
MaxClicksError
The max clicks value is invalid.
EmojiError
The emoji sequence is already in use or invalid.
RateLimitExceeded
The rate limit for the API has been exceeded.
Other(String)
Other unexpected errors from the API.